:github_url: https://github.com/Met4FoF/agentMET4FOF

agentMET4FOF - Metrological agent-based system
==============================================

.. toctree::
   :maxdepth: 1
   :caption: Getting started:

   README
   INSTALL
   UMLs
   CONTRIBUTING
   CHANGELOG


.. toctree::
   :maxdepth: 2
   :caption: Tutorials:

   tutorials


.. toctree::
   :maxdepth: 1
   :caption: Code Reference:

   agentMET4FOF_agents
   agentMET4FOF_streams
   agentMET4FOF_dashboard
   agentMET4FOF_network
   agentMET4FOF_utilities


Indices and search:
-------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


References:
-----------

.. [Bang2019]  Bang X. Yong, A. Brintrup
               Multi Agent System for Machine Learning Under Uncertainty in
               Cyber Physical Manufacturing System,
               9th Workshop on Service Oriented, Holonic and Multi-agent
               Manufacturing Systems for Industry of the Future

.. [Kok2020_1]  G. Kok, P. Harris
                "Uncertainty Evaluation for Metrologically
                Redundant Industrial Sensor Networks",
                2020 IEEE International Workshop on Metrology for Industry 4.0 & IoT,
                Roma, Italy, 2020, pp. 84-88,
                doi: `10.1109/MetroInd4.0IoT48571.2020.9138297
                <https://dx.doi.org/10.1109/MetroInd4.0IoT48571.2020.9138297>`_.

.. [Kok2020_2]  G. Kok, P. Harris
                "Quantifying Metrological Redundancy in an Industry 4.0 Environment",
                2020 IEEE International Workshop on Metrology for Industry 4.0 & IoT,
                Roma, Italy, 2020, pp. 464-468,
                doi: `10.1109/MetroInd4.0IoT48571.2020.9138235
                <https://dx.doi.org/10.1109/MetroInd4.0IoT48571.2020.9138235>`_.
